@@ -33,7 +33,7 @@ class FSP():
     verTabelaCompleta(nomeTabela,colunasExibidas='*',filtrar=False,colunaFiltragem=None,condicaoFiltragem=None,valorFiltragem=None)    
         Retornar todas as linhas das colunas selecionada de uma tabela  
     """
-    
+
     def __init__(self,nomeBancoDeDados,enderecoDoBancoDeDados='localhost',nomeUsuarioDoBancoDeDados='root',senhaDoBancoDeDados=''):
         """
         Parameters
@@ -352,17 +352,3 @@ class FSP():
             return dados
         except:
             return False
-if __name__ == '__main__':
-    teste = FSP('fsp')
-    """print(teste.conexao)
-    teste.cursor.execute("SELECT DATABASE();")
-    t = teste.cursor.fetchone()
-    print(t)"""
-    #teste.inserirDadosNaTabela('teste','numeros,nome','23,"Wanderlei"')
-    #teste.adicionarColunaTabela('teste','nome','varchar(30)','')
-    #teste.atualizarDadosNaTabela('teste','nome','Jose Wanderlei','id','>',9)
-    #print(teste.verTabelaCompleta('teste','id,nome',True,'numeros','>',9))   
-    #print(teste.verTabelaCompleta('teste'))
-    #teste.deletarDadosNaTabela('teste','id','=','8')
-    print(type(teste.conexao))
-    print(type(teste.cursor))
\ No newline at end of file
